@@ -1,5 +1,5 @@
 package List::Compare::Base::_Auxiliary;
-$VERSION = 0.45;
+$VERSION = 0.46;
 use Carp;
 @ISA = qw(Exporter);
 @EXPORT_OK = qw|
@@ -7,6 +7,7 @@ use Carp;
     _validate_seen_hash
     _validate_multiple_seenhashes
     _calculate_union_xintersection_only
+    _calculate_array_seen_only
     _calculate_seen_only
     _calculate_xintersection_only
     _calculate_union_only
@@ -44,6 +45,7 @@ use Carp;
 %EXPORT_TAGS = (
     calculate => [ qw(
         _calculate_union_xintersection_only
+        _calculate_array_seen_only
         _calculate_seen_only
         _calculate_xintersection_only
         _calculate_union_only
@@ -208,6 +210,19 @@ sub _calculate_union_xintersection_only {
     return (\%union, \%xintersection);
 }
 
+sub _calculate_array_seen_only {
+    my $aref = shift;
+    my (@seen);
+    for (my $i = 0; $i <= $#{$aref}; $i++) {
+        my %seenthis = ();
+        foreach my $el ( List::Compare::Base::_Auxiliary::_list_builder($aref, $i) ) {
+            $seenthis{$el}++;
+        }
+        push @seen, \%seenthis;
+    }
+    return \@seen;
+}
+
 sub _calculate_seen_only {
     my $aref = shift;
     my (%seen);
@@ -745,8 +760,8 @@ List::Compare::Base::_Auxiliary - Internal use only
 
 =head1 VERSION
 
-This document refers to version 0.45 of List::Compare::Base::_Auxiliary.
-This version was released February 16 2015.
+This document refers to version 0.46 of List::Compare::Base::_Auxiliary.
+This version was released February 18 2015.
 
 =head1 SYNOPSIS
 
@@ -758,7 +773,7 @@ List::Compare::Functional.  They are not intended to be publicly callable.
 James E. Keenan (jkeenan@cpan.org).  When sending correspondence, please
 include 'List::Compare' or 'List-Compare' in your subject line.
 
-Creation date:  May 20, 2002.  Last modification date:  February 16 2015.
+Creation date:  May 20, 2002.  Last modification date:  February 18 2015.
 Copyright (c) 2002-15 James E. Keenan.  United States.  All rights reserved.
 This is free software and may be distributed under the same terms as Perl
 itself.
